matminer.featurizers.structure.tests package — matminer 0.7.0 documentation

# matminer.featurizers.structure.tests package

## Submodules

## matminer.featurizers.structure.tests.base module

class `matminer.featurizers.structure.tests.base.` `StructureFeaturesTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

## matminer.featurizers.structure.tests.test_bonding module

class `matminer.featurizers.structure.tests.test_bonding.` `BondingStructureTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_GlobalInstabilityIndex`()
  `test_bob`()
  `test_bondfractions`()
  `test_min_relative_distances`()
  `test_ward_prb_2017_strhet`()

## matminer.featurizers.structure.tests.test_composite module

class `matminer.featurizers.structure.tests.test_composite.` `CompositeStructureFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_jarvisCFID`()

## matminer.featurizers.structure.tests.test_matrix module

class `matminer.featurizers.structure.tests.test_matrix.` `MatrixStructureFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_coulomb_matrix`()
  `test_orbital_field_matrix`()
  `test_sine_coulomb_matrix`()

## matminer.featurizers.structure.tests.test_misc module

class `matminer.featurizers.structure.tests.test_misc.` `MiscStructureFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_composition_features`()
  `test_ewald`()
  `test_xrd_powderPattern`()

## matminer.featurizers.structure.tests.test_order module

class `matminer.featurizers.structure.tests.test_order.` `OrderStructureFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_density_features`()
  `test_ordering_param`()
  `test_packing_efficiency`()
  `test_structural_complexity`()

## matminer.featurizers.structure.tests.test_rdf module

class `matminer.featurizers.structure.tests.test_rdf.` `StructureRDFTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_get_rdf_bin_labels`()
  `test_prdf`()
  `test_rdf_and_peaks`()
  `test_redf`()

## matminer.featurizers.structure.tests.test_sites module

class `matminer.featurizers.structure.tests.test_sites.` `StructureSitesFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_sitestatsfingerprint`()
  `test_ward_prb_2017_efftcn`()

    Test the effective coordination number attributes of Ward 2017

  `test_ward_prb_2017_lpd`()

    Test the local property difference attributes from Ward 2017

## matminer.featurizers.structure.tests.test_symmetry module

class `matminer.featurizers.structure.tests.test_symmetry.` `StructureSymmetryFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.structure.tests.base.StructureFeaturesTest`

  `test_dimensionality`()
  `test_global_symmetry`()

## Module contents